@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2001, 2013 IBM Corporation and others.
+ * Copyright (c) 2001, 2018 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -534,7 +536,7 @@ public class FileBufferModelManager {
 			IFile workspaceFile = FileBuffers.getWorkspaceFileAtLocation(location);
 			if (workspaceFile != null) {
 				IProject project = workspaceFile.getProject();
-				resolver = (URIResolver) project.getAdapter(URIResolver.class);
+				resolver = project.getAdapter(URIResolver.class);
 				if (resolver == null) {
 					resolver = new CommonURIResolver(workspaceFile);
 				}
