@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2001, 2011 IBM Corporation and others.
+ * Copyright (c) 2001, 2020 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  * 
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -73,6 +75,7 @@ import org.eclipse.wst.sse.ui.internal.taginfo.BestMatchHover;
 import org.eclipse.wst.sse.ui.internal.taginfo.ProblemAnnotationHoverProcessor;
 import org.eclipse.wst.sse.ui.internal.taginfo.TextHoverManager;
 import org.eclipse.wst.sse.ui.internal.util.EditorUtility;
+import org.eclipse.wst.sse.ui.preferences.AppearancePreferenceNames;
 
 
 /**
@@ -113,7 +116,7 @@ public class StructuredTextViewerConfiguration extends TextSourceViewerConfigura
 	
 	private final String CONTENT_ASSIST_SIZE = "contentassistsize";
 	
-	private ReconcilerHighlighter fHighlighter = null;
+	protected ReconcilerHighlighter fHighlighter = null;
 	
 	/**
 	 * Creates a structured text viewer configuration.
@@ -132,9 +135,17 @@ public class StructuredTextViewerConfiguration extends TextSourceViewerConfigura
 	 * @return IPreferenceStore
 	 */
 	private IPreferenceStore createCombinedPreferenceStore() {
+		return new ChainedPreferenceStore(createPreferenceStores());
+	}
+
+	/**
+	 * @since 1.7.0
+	 * Create the preference stores from which this viewer configuration will draw values.
+	 */
+	protected IPreferenceStore[] createPreferenceStores() {
 		IPreferenceStore sseEditorPrefs = SSEUIPlugin.getDefault().getPreferenceStore();
 		IPreferenceStore baseEditorPrefs = EditorsUI.getPreferenceStore();
-		return new ChainedPreferenceStore(new IPreferenceStore[]{sseEditorPrefs, baseEditorPrefs});
+		return new IPreferenceStore[]{sseEditorPrefs, baseEditorPrefs};
 	}
 
 	/**
@@ -267,17 +278,17 @@ public class StructuredTextViewerConfiguration extends TextSourceViewerConfigura
 				int delay = fPreferenceStore.getInt(EditorPreferenceNames.CODEASSIST_AUTOACTIVATION_DELAY);
 				fContentAssistant.setAutoActivationDelay(delay);
 
-				Color color = getColor(EditorPreferenceNames.CODEASSIST_PROPOSALS_BACKGROUND);
+				Color color = getColor(AppearancePreferenceNames.CODEASSIST_PROPOSALS_BACKGROUND);
 				fContentAssistant.setProposalSelectorBackground(color);
 
-				color = getColor(EditorPreferenceNames.CODEASSIST_PROPOSALS_FOREGROUND);
+				color = getColor(AppearancePreferenceNames.CODEASSIST_PROPOSALS_FOREGROUND);
 				fContentAssistant.setProposalSelectorForeground(color);
 
-				color = getColor(EditorPreferenceNames.CODEASSIST_PARAMETERS_BACKGROUND);
+				color = getColor(AppearancePreferenceNames.CODEASSIST_PARAMETERS_BACKGROUND);
 				fContentAssistant.setContextInformationPopupBackground(color);
 				fContentAssistant.setContextSelectorBackground(color);
 
-				color = getColor(EditorPreferenceNames.CODEASSIST_PARAMETERS_FOREGROUND);
+				color = getColor(AppearancePreferenceNames.CODEASSIST_PARAMETERS_FOREGROUND);
 				fContentAssistant.setContextInformationPopupForeground(color);
 				fContentAssistant.setContextSelectorForeground(color);
 			}
@@ -578,10 +589,10 @@ public class StructuredTextViewerConfiguration extends TextSourceViewerConfigura
 			// https://bugs.eclipse.org/bugs/show_bug.cgi?id=133731
 			// set content assist preferences
 			if (fPreferenceStore != null) {
-				Color color = getColor(EditorPreferenceNames.CODEASSIST_PROPOSALS_BACKGROUND);
+				Color color = getColor(AppearancePreferenceNames.CODEASSIST_PROPOSALS_BACKGROUND);
 				assistant.setProposalSelectorBackground(color);
 
-				color = getColor(EditorPreferenceNames.CODEASSIST_PROPOSALS_FOREGROUND);
+				color = getColor(AppearancePreferenceNames.CODEASSIST_PROPOSALS_FOREGROUND);
 				assistant.setProposalSelectorForeground(color);
 			}
 			fQuickAssistant = assistant;
@@ -623,10 +634,12 @@ public class StructuredTextViewerConfiguration extends TextSourceViewerConfigura
 		if (sourceViewer != null) {
 			//Only create reconciler if sourceViewer is present
 			if (fReconciler == null && sourceViewer != null) {
-				StructuredRegionProcessor newReconciler = new StructuredRegionProcessor();
+				IReconciler newReconciler = createReconciler(sourceViewer);
 	
 				// reconciler configurations
-				newReconciler.setDocumentPartitioning(getConfiguredDocumentPartitioning(sourceViewer));
+				if (newReconciler instanceof StructuredRegionProcessor) {
+					((StructuredRegionProcessor)newReconciler).setDocumentPartitioning(getConfiguredDocumentPartitioning(sourceViewer));
+				}
 	
 				fReconciler = newReconciler;
 			}
@@ -635,6 +648,18 @@ public class StructuredTextViewerConfiguration extends TextSourceViewerConfigura
 		
 		return reconciler;
 	}
+	
+	/**
+	 * Create IReconciler for this sourceViewer
+	 * 
+	 * @param sourceViewer the source viewer to be configured by this configuration
+	 * @return a reconciler
+	 * @since 3.10
+	 */
+	protected IReconciler createReconciler(ISourceViewer sourceViewer)
+	{
+		return new StructuredRegionProcessor();
+	}
 
 	/**
 	 * @since 2.0
