@@ -1,8 +1,10 @@
 /**********************************************************************
- * Copyright (c) 2005, 2011 IBM Corporation and others. All rights reserved.   This
+ * Copyright (c) 2005, 2015 IBM Corporation and others. All rights reserved.   This
  * program and the accompanying materials are made available under the terms of
- * the Eclipse Public License v1.0 which accompanies this distribution, and is
- * available at http://www.eclipse.org/legal/epl-v10.html
+ * the Eclipse Public License 2.0 which accompanies this distribution, and is
+ * available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  * 
  * Contributors: 
  * IBM - Initial API and implementation
@@ -16,8 +18,6 @@ import org.eclipse.osgi.util.NLS;
 
 /**
  * Strings used by SSE UI
- * 
- * @plannedfor 1.0
  */
 public class SSEUIMessages extends NLS {
 	private static final String BUNDLE_NAME = "org.eclipse.wst.sse.ui.internal.SSEUIPluginResources";//$NON-NLS-1$
@@ -432,6 +432,7 @@ public class SSEUIMessages extends NLS {
 	public static String UnknownContentTypeDialog_0;
 	public static String UnknownContentTypeDialog_1;
 	public static String UnknownContentTypeDialog_2;
+	public static String UnknownContentTypeDialog_3;
 	public static String StyledTextColorPicker_0;
 	
 	public static String TextSearchLabelProvider_matchCountFormat;
