@@ -1,8 +1,10 @@
 /*****************************************************************************
- * Copyright (c) 2004, 2013 IBM Corporation and others. All rights reserved. This
+ * Copyright (c) 2004, 2020 IBM Corporation and others. All rights reserved. This
  * program and the accompanying materials are made available under the terms
- * of the Eclipse Public License v1.0 which accompanies this distribution, and
- * is available at http://www.eclipse.org/legal/epl-v10.html
+ * of the Eclipse Public License 2.0 which accompanies this distribution, and
+ * is available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  * 
  * Contributors: IBM Corporation - initial API and implementation
  ****************************************************************************/
@@ -172,6 +174,7 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 		/*
 		 * @see IPartListener#partOpened(org.eclipse.ui.IWorkbenchPart)
 		 */
+		@Override
 		public void partOpened(IWorkbenchPart part) {
 			if (fDesignViewer instanceof AbstractTreeViewer) {
 				IDocument document = getDocument();
@@ -243,11 +246,7 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 				 * http://dev.eclipse.org/bugs/show_bug.cgi?id=11731 Will be
 				 * removed when SWT has solved the problem.
 				 */
-				window.getShell().getDisplay().asyncExec(new Runnable() {
-					public void run() {
-						handleActivation();
-					}
-				});
+				window.getShell().getDisplay().asyncExec(() -> handleActivation());
 			}
 		}
 
@@ -322,11 +321,13 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 		}
 
 		void sendInitializationData(IExecutableExtension executableExtension) {
-			try {
-				executableExtension.setInitializationData(fElement, fPropertyName, fData);
-			}
-			catch (CoreException e) {
-				Logger.logException(e);
+			if (fData != null) {
+				try {
+					executableExtension.setInitializationData(fElement, fPropertyName, fData);
+				}
+				catch (CoreException e) {
+					Logger.logException(e);
+				}
 			}
 		}
 	}
@@ -335,6 +336,7 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 	 * Internal IPropertyListener on the source page
 	 */
 	class PropertyListener implements IPropertyListener {
+		@Override
 		public void propertyChanged(Object source, int propId) {
 			switch (propId) {
 				// had to implement input changed "listener" so that
@@ -357,37 +359,31 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 								model.releaseFromRead();
 						}
 					}
+					break;
 				}
 				case IEditorPart.PROP_DIRTY : {
-					if (source == getTextEditor()) {
-						if (getTextEditor().getEditorInput() != getEditorInput()) {
-							setInput(getTextEditor().getEditorInput());
-							/*
-							 * title should always change when input changes.
-							 * create runnable for following post call
-							 */
-							Runnable runnable = new Runnable() {
-								public void run() {
-									_firePropertyChange(IWorkbenchPart.PROP_TITLE);
-								}
-							};
-							/*
-							 * Update is just to post things on the display
-							 * queue (thread). We have to do this to get the
-							 * dirty property to get updated after other
-							 * things on the queue are executed.
-							 */
-							((Control) getTextEditor().getAdapter(Control.class)).getDisplay().asyncExec(runnable);
-						}
+					if (source == getTextEditor() && ((IEditorPart)source).getEditorInput() != getEditorInput()) {
+						setInput(getTextEditor().getEditorInput());
+						/*
+						 * title should always change when input changes.
+						 * create runnable for following post call
+						 */
+						/*
+						 * Update is just to post things on the display
+						 * queue (thread). We have to do this to get the
+						 * dirty property to get updated after other
+						 * things on the queue are executed.
+						 */
+						getTextEditor().getAdapter(Control.class).getDisplay().asyncExec(() -> {
+							_firePropertyChange(IWorkbenchPart.PROP_TITLE);
+						});
 					}
 					break;
 				}
 				case IWorkbenchPart.PROP_TITLE : {
 					// update the input if the title is changed
-					if (source == getTextEditor()) {
-						if (getTextEditor().getEditorInput() != getEditorInput()) {
-							setInput(getTextEditor().getEditorInput());
-						}
+					if (source == getTextEditor() && ((IEditorPart)source).getEditorInput() != getEditorInput()) {
+						setInput(getTextEditor().getEditorInput());
 					}
 					break;
 				}
@@ -417,8 +413,10 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 
 	class StatusLineLabelProvider extends JFaceNodeLabelProvider {
 		public StatusLineLabelProvider() {
+			super();
 		}
 
+		@Override
 		public String getText(Object element) {
 			if (element == null)
 				return null;
@@ -428,9 +426,9 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 				return getText(((Attr) node).getOwnerElement());
 			}
 
-			StringBuffer s = new StringBuffer();
+			StringBuilder s = new StringBuilder();
 			if (node.getNodeType() != Node.DOCUMENT_NODE) {
-				while (node != null && node instanceof INodeNotifier) {
+				while (node instanceof INodeNotifier) {
 					INodeNotifier notifier = (INodeNotifier) node;
 					if (node.getNodeType() != Node.DOCUMENT_NODE) {
 						IJFaceNodeAdapter adapter = (IJFaceNodeAdapter) notifier.getAdapterFor(IJFaceNodeAdapter.class);
@@ -446,6 +444,7 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 			return s.toString();
 		}
 
+		@Override
 		public Image getImage(Object element) {
 			if (element == null)
 				return null;
@@ -502,7 +501,7 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 
 	/*
 	 * This method is just to make firePropertyChanged accessible from some
-	 * (anonomous) inner classes.
+	 * (anonymous) inner classes.
 	 */
 	void _firePropertyChange(int property) {
 		super.firePropertyChange(property);
@@ -708,14 +707,17 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 			fToolbar = toolbar;
 		}
 
+		@Override
 		public ImageDescriptor getImageDescriptor() {
 			return XMLEditorPluginImageHelper.getInstance().getImageDescriptor(XMLEditorPluginImageHelper.EDITOR_MENU);
 		}
 
+		@Override
 		public String getToolTipText() {
 			return XMLEditorMessages.EditorMenu_tooltip;
 		}
 
+		@Override
 		public void run() {
 			Menu menu = fMenuManager.createContextMenu(fDesignContainer);
 			Point size = fToolbar.getSize();
@@ -796,6 +798,7 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 	/**
 	 * @see org.eclipse.ui.part.MultiPageEditorPart#createSite(org.eclipse.ui.IEditorPart)
 	 */
+	@Override
 	protected IEditorSite createSite(IEditorPart editor) {
 		IEditorSite site = null;
 		if (editor == fTextEditor) {
@@ -812,6 +815,7 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 					return contributor;
 				}
 
+				@Override
 				public String getId() {
 					// sets this id so nested editor is considered xml source
 					// page
@@ -859,6 +863,7 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 		}
 	}
 
+	@Override
 	public void dispose() {
 		Logger.trace("Source Editor", "XMLMultiPageEditorPart::dispose entry"); //$NON-NLS-1$ //$NON-NLS-2$
 
@@ -935,8 +940,10 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 	 * 
 	 * @see org.eclipse.core.runtime.IAdaptable#getAdapter(java.lang.Class)
 	 */
-	public Object getAdapter(Class key) {
-		Object result = null;
+	@SuppressWarnings("unchecked")
+	@Override
+	public <T> T getAdapter(Class<T> key) {
+		T result = null;
 
 		// we extend superclass, not override it, so allow it first
 		// chance to satisfy request.
@@ -944,15 +951,11 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 
 		if (result == null) {
 			if (key == IDesignViewer.class) {
-				result = fDesignViewer;
+				result = (T) fDesignViewer;
 
 			}
 			else if (key.equals(IGotoMarker.class)) {
-				result = new IGotoMarker() {
-					public void gotoMarker(IMarker marker) {
-						XMLMultiPageEditorPart.this.gotoMarker(marker);
-					}
-				};
+				result = (T) (IGotoMarker) marker -> XMLMultiPageEditorPart.this.gotoMarker(marker);
 			}
 			else {
 				/*
@@ -1020,6 +1023,7 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 	 * @see org.eclipse.ui.IEditorPart#init(org.eclipse.ui.IEditorSite,
 	 * org.eclipse.ui.IEditorInput)
 	 */
+	@Override
 	public void init(IEditorSite site, IEditorInput input) throws PartInitException {
 		try {
 			super.init(site, input);
@@ -1048,6 +1052,7 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 	 * 
 	 * @see org.eclipse.ui.ISaveablePart#isSaveOnCloseNeeded()
 	 */
+	@Override
 	public boolean isSaveOnCloseNeeded() {
 		// overriding super class since it does a lowly isDirty!
 		if (fTextEditor != null) {
@@ -1069,17 +1074,19 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 	 * 
 	 * @see org.eclipse.ui.part.MultiPageEditorPart#pageChange(int)
 	 */
+	@Override
 	protected void pageChange(int newPageIndex) {
-		if (newPageIndex == fSourcePageIndex) {
+		if (newPageIndex == fSourcePageIndex && fDesignViewer != null) {
 			ISelectionProvider provider = fDesignViewer.getSelectionProvider();
 			if (provider != null) {
 				getTextEditor().getSelectionProvider().setSelection(provider.getSelection());
 			}
 		}
+
 		super.pageChange(newPageIndex);
 		saveLastActivePageIndex(newPageIndex);
 
-		if (newPageIndex == fDesignPageIndex) {
+		if (newPageIndex == fDesignPageIndex && fDesignViewer != null) {
 			// design page isn't an IEditorPart, therefore we have to send
 			// selection changes ourselves
 			ISelectionProvider selectionProvider = fDesignViewer.getSelectionProvider();
@@ -1096,6 +1103,7 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 		getPreferenceStore().setValue(getEditorSite().getId() + "." + IXMLPreferenceNames.LAST_ACTIVE_PAGE, newPageIndex); //$NON-NLS-1$
 	}
 
+	@Override
 	public void setFocus() {
 		super.setFocus();
 		Control control = fDesignViewer.getControl();
@@ -1104,6 +1112,7 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 		control.forceFocus();
 	}
 
+	@Override
 	public void setInitializationData(IConfigurationElement cfig, String propertyName, Object data) {
 		super.setInitializationData(cfig, propertyName, data);
 		fPageInitializer = new PageInitializationData(cfig, propertyName, data);
@@ -1114,6 +1123,7 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 	 * 
 	 * @see org.eclipse.ui.part.EditorPart#setInput(org.eclipse.ui.IEditorInput)
 	 */
+	@Override
 	protected void setInput(IEditorInput input) {
 		/*
 		 * If driven from the Source page, it's "model" may not be up to date
@@ -1176,4 +1186,4 @@ public class XMLMultiPageEditorPart extends MultiPageEditorPart implements INavi
 			fTextEditor.restoreState(memento);
 		}
 	}
-}
\ No newline at end of file
+}
