@@ -1,8 +1,10 @@
 /**********************************************************************
- * Copyright (c) 2005, 2013 IBM Corporation and others. All rights reserved.   This
+ * Copyright (c) 2005, 2019 IBM Corporation and others. All rights reserved.   This
  * program and the accompanying materials are made available under the terms of
- * the Eclipse Public License v1.0 which accompanies this distribution, and is
- * available at http://www.eclipse.org/legal/epl-v10.html
+ * the Eclipse Public License 2.0 which accompanies this distribution, and is
+ * available at https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  * 
  * Contributors: 
  * IBM - Initial API and implementation
@@ -303,6 +305,7 @@ public class XMLUIMessages extends NLS {
 	public static String StructureSelectPrevious_description;
 	public static String MESSAGE_XML_VALIDATION_MESSAGE_UI_;
 	public static String Indicate_no_grammar_specified;
+	public static String Indicate_referenced_file_error;
 	public static String Indicate_no_document_element;
 	public static String Indicate_no_grammar_specified_severities_error;
 	public static String Indicate_no_grammar_specified_severities_warning;
@@ -326,6 +329,7 @@ public class XMLUIMessages extends NLS {
 	public static String previousSibling_description;
 	public static String Use_XInclude;
     public static String Honour_all_schema_locations;   
+    public static String Resolve_external_entities;
 	public static String Open;
 	public static String Open_With;
 	public static String _UI_BUTTON_SORT;
@@ -346,6 +350,9 @@ public class XMLUIMessages extends NLS {
 	public static String Tag_name_missing;
 	public static String Whitespace_at_start;
 
+	public static String QuickOutlineShowAttributes;
+	public static String QuickOutlineHideAttributes;
+
 	static {
 		// load message values from bundle file
 		NLS.initializeMessages(BUNDLE_NAME, XMLUIMessages.class);
