@@ -1,9 +1,11 @@
 /*******************************************************************************
- * Copyright (c) 2010 IBM Corporation and others.
+ * Copyright (c) 2010, 2020 IBM Corporation and others.
  * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
@@ -20,6 +22,8 @@ import java.util.Properties;
 import java.util.Vector;
 
 import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.jface.text.BadLocationException;
+import org.eclipse.jface.text.IDocument;
 import org.eclipse.jface.text.ITextViewer;
 import org.eclipse.jface.text.contentassist.ICompletionProposal;
 import org.eclipse.wst.sse.core.StructuredModelManager;
@@ -129,7 +133,7 @@ public abstract class AbstractXMLCompletionProposalComputer implements ICompleti
 					}
 					if (sModel != null) {
 						IDOMDocument docNode = ((IDOMModel) sModel).getDocument();
-						contentAssistRequest = new ContentAssistRequest(docNode, docNode, sdRegion, completionRegion, documentPosition, 0, null);
+						contentAssistRequest = new ContentAssistRequest(docNode, docNode, sdRegion, completionRegion, documentPosition - matchString.length(), matchString.length(), null);
 						addEmptyDocumentProposals(contentAssistRequest, context);
 					}
 				}
@@ -604,7 +608,7 @@ public abstract class AbstractXMLCompletionProposalComputer implements ICompleti
 		ContentAssistRequest contentAssistRequest = null;
 
 		// setup to add children at the content node's position
-		contentAssistRequest = new ContentAssistRequest(nodeAtOffset, node, getStructuredDocumentRegion(documentPosition), completionRegion, documentPosition, 0, matchString);
+		contentAssistRequest = new ContentAssistRequest(nodeAtOffset, node, getStructuredDocumentRegion(documentPosition), completionRegion, documentPosition - matchString.length(), matchString.length(), matchString);
 		if ((node != null) && (node.getNodeType() == Node.DOCUMENT_NODE) && (((Document) node).getDoctype() == null)) {
 			addStartDocumentProposals(contentAssistRequest, context);
 		}
@@ -1049,8 +1053,20 @@ public abstract class AbstractXMLCompletionProposalComputer implements ICompleti
 			matchString = ""; //$NON-NLS-1$
 		}
 		else if (regionType == DOMRegionContext.XML_CONTENT) {
+			int start = offset;
+			int end = offset;
+			IDocument document = parent.getParentDocument();
+			try {
+				while (start > 0 && !Character.isWhitespace(document.getChar(start - 1))) {
+					start--;
+				}
+				matchString = document.get(start, end - start);
+			}
+			catch (BadLocationException e) {
+				Logger.logException(e);
 			matchString = ""; //$NON-NLS-1$
 		}
+		}
 		else {
 			if ((parent.getText(aRegion).length() > 0) && (parent.getStartOffset(aRegion) < offset)) {
 				matchString = parent.getText(aRegion).substring(0, offset - parent.getStartOffset(aRegion));
